@@ -7,5 +7,5 @@ __author__ = "Paul Richter"
 __credits__ = "ETH Zurich"
 
 from . import graph_numba
-from . import make_net
+#from . import make_net
 from . import convert_pure
